@@ -3,7 +3,7 @@ package CGI::Wiki::Plugin::Diff;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use base 'CGI::Wiki::Plugin';
 use Algorithm::Diff;
@@ -99,7 +99,7 @@ sub _intradiff {
     my $re_wordmatcher = qr(
             &.+?;                   #HTML special characters e.g. &lt;
             |<br />                 #Line breaks
-            |\w+[,.;:?!"]?\s+       #Word with trailing spaces  "
+            |\w+\s+       	    #Word with trailing spaces 
             |.                      #Any other single character
     )xs;
                                              
